@@ -74,10 +74,41 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = yha
 #' @rdname explain
 explain <- explain.default
 
-yhat <- function(X.model, newdata, ...) {
-  if ("lm" %in% class(X.model)) {
-    stats::predict(X.model, newdata, ...)
+#' Wrapper over the predict function
+#'
+#' This function is just a wrapper over the predict function.
+#' It sets different default parameters for models from different classes,
+#' like for classification random Forest is forces the output to be probabilities not classes itself.
+#'
+#' @param X.model object - a model to be explained
+#' @param newdata data.frame or matrix - observations for prediction
+#' @param ... other parameters that will be passed to the predict function
+#'
+#' @return An numeric matrix of predictions
+#'
+#' @rdname yhat
+#' @export
+yhat <- function (X.model, newdata, ...)
+  UseMethod("yhat")
+
+#' @rdname yhat
+#' @export
+yhat.lm <- function(X.model, newdata, ...) {
+  predict(X.model, newdata, ...)
+}
+
+#' @rdname yhat
+#' @export
+yhat.randomForest <- function(X.model, newdata, ...) {
+  if (X.model$type == "classification") {
+    predict(X.model, newdata, type = "prob", ...)
   } else {
-    as.numeric(stats::predict(X.model, newdata, ...))
+    predict(X.model, newdata, ...)
   }
 }
+
+#' @rdname yhat
+#' @export
+yhat.default <- function(X.model, newdata, ...) {
+  as.numeric(predict(X.model, newdata, ...))
+}
