@@ -1,8 +1,3 @@
 .onAttach <- function(...) {
   packageStartupMessage("Welcome to DALEX (version: ", utils::packageVersion("DALEX"), ").")
 }
-
-## no S4 methodology here; speedup :
-.noGenerics <- TRUE
-
-
